@@ -1,4 +1,3 @@
-# print("Starting")
 import datetime
 import functools
 import io
@@ -51,7 +50,6 @@ def generate_nav(pages):
     page_name_stack = []
 
     for page in pages:
-        print(page.path, page_name_stack)
         page.subpages = []
         parts = page.path.split('/')
         max_index = 0
@@ -139,7 +137,6 @@ def upload_image():
         filename = random.choice(string.ascii_lowercase) + filename
 
     image.save(os.path.join(config.upload_folder, filename), 'webp')
-    print(filename)
     # with open(os.path.join(config.upload_folder, filename), 'wb') as f:
     #    data.seek(0)
     #    f.write(data.read())
